pub enum Reason {
NoConservativeHardStop,
}Expand description
Positive policy reason explaining why no conservative hard stop blocked the workflow.
Variants
NoConservativeHardStop
No conservative hard stop outcome in the automation authority or human-review policy.