pub struct Decision {
pub eligibility: Eligibility,
pub required_review: Option<ReviewGate>,
}Expand description
Group-play eligibility decision plus any review gate that must be satisfied first.
Fields
eligibility: EligibilityPolicy input eligibility used to explain or enforce an automation gate.
required_review: Option<ReviewGate>Policy input required review used to explain or enforce an automation gate.
Implementations